.. _exploration:

=================
Exploration
=================

This is the documentation for Exploration functions. 

If you are interested in feature selection, please see `Features <general_documents/feature_extraction.md>`_ for further details on which features to use.

Incident curves information
--------------------------
.. autofunction:: sam.exploration.incident_curves
.. autofunction:: sam.exploration.incident_curves_information

Retrieve correlation features
-----------------------------
.. autofunction:: sam.exploration.lag_correlation
.. autofunction:: sam.exploration.top_score_correlations
.. autofunction:: sam.exploration.top_n_correlations